@@ -1,13 +1,23 @@
 package XML::DOM2::DOM::NameSpace;
 
+=head1 NAME
+
+  XML::DOM2::DOM::NameSpace
+
+=head1 DESCRIPTION
+
+  NameSpace base class for all attributes and elements
+
+=head1 METHODS
+
+=cut
+
 use strict;
 use Carp;
 
-=head2 name
+=head2 $element->name()
 
-$name = $attribute->name;
-
-Returns the attributes full name with namespace prefix.
+  Returns the attributes full name with namespace prefix.
 
 =cut
 sub name
@@ -17,11 +27,9 @@ sub name
 	return ($prefix ? $prefix.':' : '').$self->localName;
 }
 
-=head2 localName
+=head2 $element->localName()
 
-$name = $attribute->localName;
-
-Returns the attribute name without name space prefix.
+  Returns the attribute name without name space prefix.
 
 =cut
 sub localName
@@ -31,11 +39,9 @@ sub localName
 	return $self->{'name'};
 }
 
-=head2 prefix
+=head2 $element->namespaceURI()
 
-$uri = $attribute->namespaceURI;
-
-Returns the URI of the attributes namespace.
+  Returns the URI of the attributes namespace.
 
 =cut
 sub namespaceURI
@@ -45,11 +51,9 @@ sub namespaceURI
 	return $self->namespace->ns_uri;
 }
 
-=head2 prefix
+=head2 $element->prefix()
 
-$prefix = $attribute->prefix;
-
-Returns the attributes namespace prefix, returns undef if the namespace is the same as the owning element.
+  Returns the attributes namespace prefix, returns undef if the namespace is the same as the owning element.
 
 =cut 
 sub prefix
@@ -63,10 +67,24 @@ sub prefix
 	return $self->namespace->ns_prefix;
 }
 
+=head2 $element->namespace()
+
+  Return the namespace string this element or attribute belongs to.
+
+=cut
 sub namespace
 {
 	my ($self) = @_;
 	return $self->{'namespace'};
 }
 
-return 1;
+=head1 COPYRIGHT
+
+Martin Owens, doctormo@cpan.org
+
+=head1 SEE ALSO
+
+L<XML::DOM2>
+
+=cut
+1;
